@@ -560,12 +560,10 @@ unsigned default_ipv4_prefix(struct in_addr net)
 
 char *ipv4_prefix_to_hosts(char *hosts, unsigned hosts_size, unsigned prefix)
 {
-	unsigned tmp;
-
 	if (prefix >= 31) {
 		snprintf(hosts, hosts_size, "%s", p2_table(32 - prefix));
 	} else {
-		tmp = (1 << (32 - prefix)) - 2;
+		unsigned tmp = (1 << (32 - prefix)) - 2;
 		snprintf(hosts, hosts_size, "%u", tmp);
 	}
 	return hosts;
@@ -1067,11 +1065,11 @@ static char *generate_ip_network(unsigned prefix, unsigned flags)
 static
 int str_to_prefix(unsigned *flags, const char *prefixStr, unsigned fix)
 {
-	int prefix = -1, r;
+	int prefix = -1;
 	if (!((*flags) & FLAG_IPV6) && strchr(prefixStr, '.')) {	/* prefix is 255.x.x.x */
 		prefix = ipv4_mask_to_int(prefixStr);
 	} else {
-		r = safe_atoi(prefixStr, &prefix);
+		int r = safe_atoi(prefixStr, &prefix);
 		if (r != 0) {
 			return -1;
 		}
@@ -1140,7 +1138,7 @@ void usage(unsigned verbose)
 		fprintf(stderr, "                                  the supplied prefix or mask.\n");
 		fprintf(stderr, "  -S, --split=PREFIX              Split the provided network using the\n");
 		fprintf(stderr, "                                  provided prefix/netmask\n");
-		fprintf(stderr, "  -d, --deagrregate=IP1-IP2       Deaggregate the provided address range\n");
+		fprintf(stderr, "  -d, --deaggregate=IP1-IP2       Deaggregate the provided address range\n");
 		fprintf(stderr, "  -i, --info                      Print information on the provided IP address\n");
 		fprintf(stderr, "                                  (default)\n");
 		fprintf(stderr, "      --all-info                  Print verbose information on the provided IP\n");
@@ -1389,12 +1387,11 @@ int main(int argc, char **argv)
 	int prefix = -1, splitPrefix = -1;
 	ip_info_st info;
 	int r = 0;
-	int c;
 	unsigned jsonchain = JSON_FIRST;
 	enum app_t app = 0;
 
 	while (1) {
-		c = getopt_long(argc, argv, "S:cr:i46abho:gmnpjsvd:", long_options, NULL);
+		int c = getopt_long(argc, argv, "S:cr:i46abho:gmnpjsvd:", long_options, NULL);
 		if (c == -1)
 			break;
 
@@ -1735,7 +1732,10 @@ int main(int argc, char **argv)
 			default_printf(&jsonchain, "Address:\t", ADDRESS_NAME, "%s", info.ip);
 		}
 
-		if (!single_host) {
+		if (single_host && info.hostname)
+			default_printf(&jsonchain, "Hostname:\t", HOSTNAME_NAME, "%s", info.hostname);
+
+		if (!single_host || (flags & FLAG_JSON)) {
 			if (! (flags & FLAG_JSON)) {
 				if (info.expanded_network) {
 					default_printf(&jsonchain, "Full Network:\t", FULL_NETWORK_NAME, "%s/%u", info.expanded_network, info.prefix);
@@ -1760,7 +1760,7 @@ int main(int argc, char **argv)
 		if ((flags & FLAG_SHOW_ALL_INFO) && info.reverse_dns)
 			default_printf(&jsonchain, "Reverse DNS:\t", REVERSEDNS_NAME, "%s", info.reverse_dns);
 
-		if (!single_host) {
+		if (!single_host || (flags & FLAG_JSON)) {
 			output_separate(&jsonchain);
 
 			if (info.type)
@@ -1781,8 +1781,6 @@ int main(int argc, char **argv)
 				default_printf(&jsonchain, "Hosts/Net:\t", ADDRESSES_NAME, "%s", info.hosts);
 
 		} else {
-			if (info.hostname)
-				default_printf(&jsonchain, "Hostname:\t", HOSTNAME_NAME, "%s", info.hostname);
 
 			if (info.type)
 				dist_printf(&jsonchain, "Address space:\t", ADDRSPACE_NAME, "%s", info.type);
